@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.18 2004/01/01 22:54:11 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.19.6.1 2004/07/10 18:45:22 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -28,15 +28,15 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_EMBED_SINGLE		(ephy_embed_single_get_type ())
 #define EPHY_EMBED_SINGLE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingle))
-#define EPHY_EMBED_SINGLE_IFACE(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleIFace))
+#define EPHY_EMBED_SINGLE_IFACE(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleIface))
 #define EPHY_IS_EMBED_SINGLE(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_EMBED_SINGLE))
 #define EPHY_IS_EMBED_SINGLE_IFACE(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED_SINGLE))
-#define EPHY_EMBED_SINGLE_GET_IFACE(i)	(G_TYPE_INSTANCE_GET_INTERFACE ((i), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleIFace))
+#define EPHY_EMBED_SINGLE_GET_IFACE(i)	(G_TYPE_INSTANCE_GET_INTERFACE ((i), EPHY_TYPE_EMBED_SINGLE, EphyEmbedSingleIface))
 
 typedef struct EphyEmbedSingle		EphyEmbedSingle;
-typedef struct EphyEmbedSingleIFace	EphyEmbedSingleIFace;
+typedef struct EphyEmbedSingleIface	EphyEmbedSingleIface;
 
-struct EphyEmbedSingleIFace
+struct EphyEmbedSingleIface
 {
 	GTypeInterface base_iface;
 
@@ -56,6 +56,7 @@ struct EphyEmbedSingleIFace
 					 const char* url);
 	GList *	(* get_font_list)	(EphyEmbedSingle *shell,
 					 const char *langGroup);
+	void	(* print_setup)		(EphyEmbedSingle *single);
 };
 
 GType	ephy_embed_single_get_type		(void);
@@ -73,6 +74,8 @@ void	ephy_embed_single_load_proxy_autoconf	(EphyEmbedSingle *shell,
 GList  *ephy_embed_single_get_font_list		(EphyEmbedSingle *shell,
 						 const char *langGroup);
 
+void	ephy_embed_single_print_setup		(EphyEmbedSingle *single);
+
 G_END_DECLS
 
 #endif
