@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.30.6.5 2004/07/10 18:45:22 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.30.6.6 2004/10/30 18:14:08 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -174,6 +174,24 @@ ephy_embed_base_init (gpointer g_class)
 			      1,
 			      G_TYPE_FLOAT);
 
+		g_signal_new ("ge_modal_alert",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, modal_alert),
+			      g_signal_accumulator_true_handled, NULL,
+			      ephy_marshal_BOOLEAN__VOID,
+			      G_TYPE_BOOLEAN,
+			      0);
+
+		g_signal_new ("ge_modal_alert_closed",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, modal_alert_closed),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
+
 		initialized = TRUE;
 	}
 }
