@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.46.6.1 2004/05/20 18:04:57 chpe Exp $
+ *  $Id: ephy-history.c,v 1.46.6.2 2004/11/14 11:49:06 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -231,7 +231,7 @@ remove_obsolete_pages (EphyHistory *eb)
         g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->pages);
-	for (i = children->len -1; i >= 0; i--)
+	for (i = (int) children->len -1; i >= 0; i--)
 	{
 		EphyNode *kid;
 
