@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.84.4.1 2004/07/10 18:45:23 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.84.4.3 2004/09/07 21:23:57 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -271,7 +271,7 @@ save_yourself_cb (GnomeClient *client,
 		  EphyShell *shell)
 {
 	char *argv[] = { "epiphany", "--load-session", NULL };
-	char *discard_argv[] = { "rm", "-r", NULL };
+	char *discard_argv[] = { "rm", "-f", NULL };
 	EphySession *session;
 	char *tmp, *save_to;
 
@@ -580,11 +580,11 @@ ephy_shell_new_tab (EphyShell *shell,
 		    flags & EPHY_NEW_TAB_APPEND_GROUPED)) &&
 		  !(flags & EPHY_NEW_TAB_APPEND_LAST);
 
-	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_embed != NULL)
+	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_tab != NULL)
 	{
 		nb = ephy_window_get_notebook (window);
 		position = gtk_notebook_page_num (GTK_NOTEBOOK (nb),
-						  GTK_WIDGET (previous_embed)) + 1;
+						  GTK_WIDGET (previous_tab)) + 1;
 	}
 	else
 	{
